==> nateon-1.0.1.192.tar.bz2: nateon-1.0/nateon/network/serversocket.cpp <==
/***************************************************************************
 *   Copyright (C) 2008 by SK Communications.                              *
 *   http://kldp.net/projects/nateon/                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 3 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

// Qt includes
#include <qsocket.h>

// local includes
#include "serversocket.h"

////////////////////////////////////////////////////////////////////////////////

ServerSocket::ServerSocket(int port, QObject* parent, const char* name)
	: QServerSocket(port, 1, parent, name)
{
}

////////////////////////////////////////////////////////////////////////////////


ServerSocket::~ServerSocket()
{
}

////////////////////////////////////////////////////////////////////////////////

void ServerSocket::newConnection(int socketfd)
{
	QSocket* socket = new QSocket(parent());
	socket->setSocket(socketfd);

	emit newClient(socket);
}

// end of file
#include "serversocket.moc"

==> nateon-1.0.1.275.tar.bz2: nateon-1.0/nateon/network/serversocket.cpp <==
/***************************************************************************
 *   Copyright (C) 2008 by SK Communications.                              *
 *   http://kldp.net/projects/nateon/                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 3 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

// Qt includes
#include <qsocket.h>

// local includes
#include "serversocket.h"

////////////////////////////////////////////////////////////////////////////////

ServerSocket::ServerSocket(int port, QObject* parent, const char* name)
        : QServerSocket(port, 1, parent, name) {
}

////////////////////////////////////////////////////////////////////////////////


ServerSocket::~ServerSocket() {
}

////////////////////////////////////////////////////////////////////////////////

void ServerSocket::newConnection(int socketfd) {
    QSocket* socket = new QSocket(parent());
    socket->setSocket(socketfd);

    emit newClient(socket);
}

// end of file
#include "serversocket.moc"
